/*
 *
 *  kryptomedia- Another KDE cryto media application.
 *
 *  Copyright (C) 2006  Daniel Gollub <dgollub@suse.de>
 *
 *
 *  This file is part of kryptomedia.
 *
 *  kbluetooth is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  libkbluetooth is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with libkbluetooth; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *
 */

#include "dialog.h"

Dialog *Dialog::_ctx = NULL;

Dialog::Dialog(QString vendor, QString product, QString device, QString deviceType) :
	KDialogBase(NULL, "Dialog", true, "Decrypt Storage Device", (Cancel|User1), User1, false, KGuiItem(i18n("Decrypt"), "decrypted" ))
{
	_ctx = this;

	mDevice = device;

	decryptDialog = new DecryptDialog(this);


	decryptDialog->errorBox->hide();
	decryptDialog->descLabel->setText(decryptDialog->descLabel->text().arg(vendor).arg(product).arg(device));
	decryptDialog->descLabel->adjustSize();
	decryptDialog->adjustSize();

	setDeviceIcon( deviceType );

	enableButton( User1, false );
	

	connect(decryptDialog->passwordEdit, SIGNAL (textChanged(const QString &)), this, SLOT (slotPasswordChanged(const QString &)));

	setMainWidget(decryptDialog);
}

Dialog::~Dialog()
{
	delete decryptDialog;
}

void Dialog::setDeviceIcon(QString deviceType)
{
	QString deviceIcon;

	if ( deviceType == "memory_stick"
		|| deviceType == "cdrom"
		|| deviceType == "sd_mmc"
		|| deviceType == "compact_flash"
		|| deviceType == "smart_media"
		|| deviceType == "zip" ) {

		deviceIcon = QString("%1_unmount").arg(deviceType);
	} else {
		deviceIcon = QString("hdd_unmount");
	}

	QPixmap pixmap = KGlobal::iconLoader()->loadIcon(deviceIcon, KIcon::NoGroup, KIcon::SizeLarge);
	decryptDialog->encryptedIcon->setPixmap( pixmap );
}

QString Dialog::getPassword()
{
	return decryptDialog->passwordEdit->text();
}

void Dialog::slotDialogError(QString errorName, QString errorMsg)
{
	kdDebug() << __func__ << "(" << errorName << ", " << errorMsg << " )" << endl;

	QString error = QString::null;

	if ( errorName == "org.freedesktop.Hal.Device.Volume.Crypto.SetupPasswordError" ) {
		error = QString( i18n("Wrong password!") );
	} else if ( errorName == "org.freedesktop.Hal.Device.Volume.Crypto.CryptSetupMissing" ) {
		error = QString( i18n("Decryption failed! Application \"cryptsetup\" not found. Is package \"util-linux-crypto\" installed?") );
	} else if ( errorName == "org.freedesktop.Hal.Device.Volume.Crypto.SetupError" ) {
		error = QString( i18n("%1 is already decrypted!").arg(mDevice) );
	} else {
		error = errorMsg;
	}

	decryptDialog->errorLabel->setText(QString("<b>%1</b>").arg(error));
	decryptDialog->errorBox->show();
//	decryptDialog->adjustSize();
//	decryptDialog->errorBox->adjustSize();

	
}

void Dialog::slotPasswordChanged(const QString &text)
{
	enableButton( User1, !text.isEmpty() );
}

#include "dialog.moc"
